summaryrefslogtreecommitdiffstats
path: root/win/tclWinPipe.c
diff options
context:
space:
mode:
Diffstat (limited to 'win/tclWinPipe.c')
-rw-r--r--win/tclWinPipe.c4
1 files changed, 2 insertions, 2 deletions
diff --git a/win/tclWinPipe.c b/win/tclWinPipe.c
index eda9fe0..47af1e1 100644
--- a/win/tclWinPipe.c
+++ b/win/tclWinPipe.c
@@ -851,7 +851,7 @@ TclpCloseFile(
* Results:
* Returns the process id for the child process. If the pid was not known
* by Tcl, either because the pid was not created by Tcl or the child
* process has already been reaped, (size_t)-1 is returned.
*
* Side effects:
* None.
@@ -875,7 +875,7 @@ TclpGetPid(
}
}
Tcl_MutexUnlock(&pipeMutex);
- return (size_t)-1;
+ return TCL_IO_FAILURE;
}
/*
@@ -851,7 +851,7 @@ TclpCloseFile(
* Returns the process id for the child process. If the pid was not known
* by Tcl, either because the pid was not created by Tcl or the child
- * process has already been reaped, (size_t)-1 is returned.
+ * process has already been reaped, TCL_IO_FAILURE is returned.
*
* Side effects: